pysonos
=======

This is a fork of the `SoCo`_ (Sonos Controller) project, please go there for
a supported version.

The pysonos fork adds just a few bits needed for `Home Assistant`_, bridging
the gap in release frequency between the two projects.


License
-------

pysonos is released under the `MIT license`_.


.. _Home Assistant: https://www.home-assistant.io
.. _MIT license: http://www.opensource.org/licenses/mit-license.php
.. _SoCo: https://github.com/SoCo/SoCo
